pywurfl.algorithms.wurfl.handlers

Package pywurfl :: Package algorithms :: Package wurfl :: Module handlers |
[hide private]
[frames] | no frames]

# Module handlers

source code

This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL.

A description of the way the following source is intended to work can be found within the source for the original Java API implementation here: http://sourceforge.net/projects/wurfl/files/WURFL Java API/

The original Java code is GPLd and Copyright (c) 2008-2009 WURFL-Pro srl

Version: 1.0.1

Author: Armand Lynch <lyncha@users.sourceforge.net>

Copyright: Copyright 2010, Armand Lynch

License: LGPL

Classes | [hide private]
| AbstractMatcher
| AlcatelMatcher
| AndroidMatcher
| AOLMatcher
| AppleMatcher
| BenQMatcher
| BlackberryMatcher
| BotMatcher
| CatchAllMatcher
| ChromeMatcher
| DoCoMoMatcher
| FirefoxMatcher
| GrundigMatcher
| HTCMatcher
| KDDIMatcher
| KonquerorMatcher
| KyoceraMatcher
| LGMatcher
| MitsubishiMatcher
| MotorolaMatcher
| MSIEMatcher
| NecMatcher
| NokiaMatcher
| OperaMatcher
| OperaMiniMatcher
| PanasonicMatcher
| PantechMatcher
| PhilipsMatcher
| PortalmmmMatcher
| QtekMatcher
| SafariMatcher
| SagemMatcher
| SamsungMatcher
| SanyoMatcher
| SharpMatcher
| SiemensMatcher
| SonyEricssonMatcher
| SPVMatcher
| ToshibaMatcher
| VodafoneMatcher
| WindowsCEMatcher

Variables | [hide private]
| __doc__ = ``...``
| __url__ = ``'``http://celljam.net/``'``
| handlers = `[NokiaMatcher(), AndroidMatcher(normalizers.android`...``

Variables Details | [hide private]

  ### __doc__ Value:
      """
      This module contains the supporting classes for the Two Step Analysis
      user agent
      algorithm that is used as the primary way to match user agents with th
      e Java API
      for the WURFL.

      A description of the way the following source is intended to work can
      ...

  ### handlers Value:
      [NokiaMatcher(), AndroidMatcher(normalizers.android), SonyEricssonMatc
      her(), MotorolaMatcher(), BlackberryMatcher(), SiemensMatcher(), Sagem
      Matcher(), SamsungMatcher(), PanasonicMatcher(), NecMatcher(), QtekMat
      cher(), MitsubishiMatcher(), PhilipsMatcher(), LGMatcher(), AppleMatch
      er(), KyoceraMatcher(), AlcatelMatcher(), SharpMatcher(), SanyoMatcher
      (), BenQMatcher(), PantechMatcher(), ToshibaMatcher(), GrundigMatcher(
      ), HTCMatcher(), BotMatcher(), SPVMatcher(), WindowsCEMatcher(), Porta
      lmmmMatcher(), DoCoMoMatcher(), KDDIMatcher(), VodafoneMatcher(), Oper
      ...